define([
    'jquery',
    'mage/translate'
], function ($) {
    'use strict';

    $.widget('pinpoint.taxSwitch', {
        options: {},
        defaults: {
            localStorageKey: 'tax_switch_state'
        },

        /**
         * @private
         */
        _create: function () {
            this.switch = $(this.element);
            this.includingTaxPrices = $('.price-' + this.options.priceType + ' ' + this.options.selectors.includingTaxPrice);
            this.excludingTaxPrices = $('.price-' + this.options.priceType + ' ' + this.options.selectors.excludingTaxPrice);
            this.includingTaxLabel = $(this.options.selectors.includingTaxLabel);
            this.excludingTaxLabel = $(this.options.selectors.excludingTaxLabel);
            this._bind();
            this._setInitialState();
        },

        /**
         * @private
         */
        _bind: function () {
            $(this.switch).on('change', this.toggleSwitch.bind(this));
        },

        /**
         * @private
         */
        _setInitialState: function () {
            if (this._isChecked() && this._getStateFromLocalStorage() !== 'true') {
                this._setStateToLocalStorage(true);
                this.showIncludingTaxPrices();
                this.showIncludingTaxLabel();
            } else {
                this._setStateToLocalStorage(false);
                this.showExcludingTaxPrices();
                this.showExcludingTaxLabel();
            }
        },

        /**
         * @returns {string}
         * @private
         */
        _getStateFromLocalStorage: function () {
            return localStorage.getItem(this.defaults.localStorageKey);
        },

        /**
         * @param state
         * @private
         */
        _setStateToLocalStorage: function (state) {
            localStorage.setItem(this.defaults.localStorageKey, state);
        },

        /**
         * @returns {*|jQuery}
         * @private
         */
        _isChecked: function () {
           return $(this.switch).is(':checked');
        },

        /**
         * Show excluding tax prices
         */
        showExcludingTaxPrices: function () {
            $(this.includingTaxPrices).hide();
            $(this.excludingTaxPrices).show();
        },

        /**
         * Show including tax prices
         */
        showIncludingTaxPrices: function () {
            $(this.excludingTaxPrices).hide();
            $(this.includingTaxPrices).show();
        },

        /**
         * Show including tax label
         */
        showIncludingTaxLabel: function () {
            $(this.excludingTaxLabel).hide();
            $(this.includingTaxLabel).show();
        },

        /**
         * Show excluding tax label
         */
        showExcludingTaxLabel: function () {
            $(this.includingTaxLabel).hide();
            $(this.excludingTaxLabel).show();
        },

        /**
         * Toggle switch press
         */
        toggleSwitch: function () {
            if (this._isChecked()) {
                this._setStateToLocalStorage(true);
                this.showIncludingTaxLabel();
                this.showIncludingTaxPrices();
            } else {
                this._setStateToLocalStorage(false);
                this.showExcludingTaxLabel();
                this.showExcludingTaxPrices();
            }
        },
    })

    return $.pinpoint.taxSwitch;
});
